==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftRa3.md <==
# AmazonRedshiftRa3


```text
aws-20210730/Resource/Analytics/AmazonRedshiftRa3
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')
```



| Illustration | AmazonRedshiftRa3 | AmazonRedshiftRa3Card | AmazonRedshiftRa3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3.png) | ![illustration for AmazonRedshiftRa3](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3.Local.png) | ![illustration for AmazonRedshiftRa3Card](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3Card.Local.png) | ![illustration for AmazonRedshiftRa3Group](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3Group.Local.png) |




## AmazonRedshiftRa3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3('AmazonRedshiftRa3', 'Amazon Redshift Ra3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3('AmazonRedshiftRa3', 'Amazon Redshift Ra3', 'an optional tech label')
@enduml
```

## AmazonRedshiftRa3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Card
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Card('AmazonRedshiftRa3Card', 'Amazon Redshift Ra3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Card
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Card('AmazonRedshiftRa3Card', 'Amazon Redshift Ra3 Card', 'an optional description')
@enduml
```

## AmazonRedshiftRa3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Group
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Group('AmazonRedshiftRa3Group', 'Amazon Redshift Ra3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Group
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Group('AmazonRedshiftRa3Group', 'Amazon Redshift Ra3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftRa3.md <==
# AmazonRedshiftRa3


```text
aws-20210730/Resource/Analytics/AmazonRedshiftRa3
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')
```



| Illustration | AmazonRedshiftRa3 | AmazonRedshiftRa3Card | AmazonRedshiftRa3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3.png) | ![illustration for AmazonRedshiftRa3](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3.Local.png) | ![illustration for AmazonRedshiftRa3Card](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3Card.Local.png) | ![illustration for AmazonRedshiftRa3Group](../../../aws-20210730/Resource/Analytics/AmazonRedshiftRa3Group.Local.png) |




## AmazonRedshiftRa3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3('AmazonRedshiftRa3', 'Amazon Redshift Ra3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3('AmazonRedshiftRa3', 'Amazon Redshift Ra3', 'an optional tech label')
@enduml
```

## AmazonRedshiftRa3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Card
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Card('AmazonRedshiftRa3Card', 'Amazon Redshift Ra3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Card
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Card('AmazonRedshiftRa3Card', 'Amazon Redshift Ra3 Card', 'an optional description')
@enduml
```

## AmazonRedshiftRa3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Group
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Group('AmazonRedshiftRa3Group', 'Amazon Redshift Ra3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftRa3Group
include('aws-20210730/Resource/Analytics/AmazonRedshiftRa3')

' renders the element
AmazonRedshiftRa3Group('AmazonRedshiftRa3Group', 'Amazon Redshift Ra3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
